@@ -15,8 +15,10 @@
 import re
 from abc import ABC
 from typing import List, Optional, TypeVar
+
 from hspylib.core.tools.commons import sysout
 from hspylib.modules.cli.icons.font_awesome.form_icons import FormIcons
+from hspylib.modules.cli.icons.font_awesome.nav_icons import NavIcons
 from hspylib.modules.cli.keyboard import Keyboard
 from hspylib.modules.cli.vt100.vt_codes import vt_print
 from hspylib.modules.cli.vt100.vt_colors import VtColors
@@ -50,8 +52,8 @@ class MenuSelect(ABC):
     UNSELECTED = ' '
     SELECTED = FormIcons.SELECTOR
 
-    NAV_ICONS = '\u2191\u2193'
-    NAV_FMT = "\n{}[Enter] Select  [{}] Navigate  [Q] Quit  [1..{}] Goto: %EL0%"
+    NAV_ICONS = NavIcons.compose(NavIcons.UP, NavIcons.DOWN)
+    NAV_BAR = f"[Enter] Select  [{NAV_ICONS}] Navigate  [Esc] Quit  [1..%TO%] Goto: %EL0%"
 
     def __init__(
         self,
@@ -125,7 +127,7 @@ class MenuSelect(ABC):
             else:
                 break
 
-        sysout(self.NAV_FMT.format(nav_color.placeholder(), self.NAV_ICONS, str(length)), end='')
+        sysout(f"\n{nav_color.placeholder()}{self.NAV_BAR.replace('%TO%', str(length))}", end='')
         self.re_render = False
 
     # pylint: disable=too-many-branches
@@ -143,14 +145,14 @@ class MenuSelect(ABC):
                 sysout(f"{keypress.value}", end='')
                 index_len = 1
                 while len(typed_index) < len(str(length)):
-                    numpress = Keyboard.read_keystroke()
-                    if not numpress:
+                    num_press = Keyboard.read_keystroke()
+                    if not num_press:
                         break
-                    if not re.match(r'^[0-9]*$', numpress.value):
+                    if not re.match(r'^[0-9]*$', num_press.value):
                         typed_index = None
                         break
-                    typed_index = f"{typed_index}{numpress.value if numpress else ''}"
-                    sysout(f"{numpress.value if numpress else ''}", end='')
+                    typed_index = f"{typed_index}{num_press.value if num_press else ''}"
+                    sysout(f"{num_press.value if num_press else ''}", end='')
                     index_len += 1
                 # Erase the index typed by the user
                 sysout(f"%CUB({index_len})%%EL0%", end='')
@@ -173,6 +175,18 @@ class MenuSelect(ABC):
                 if self.sel_index + 1 < length:
                     self.sel_index += 1
                     self.re_render = True
+            elif keypress == Keyboard.VK_TAB:
+                page_index = min(self.show_to + self.diff_index, length)
+                self.show_to = max(page_index, self.diff_index)
+                self.show_from = self.show_to - self.diff_index
+                self.sel_index = self.show_from
+                self.re_render = True
+            elif keypress == Keyboard.VK_SHIFT_TAB:
+                page_index = max(self.show_from - self.diff_index, 0)
+                self.show_from = min(page_index, self.diff_index)
+                self.show_to = self.show_from + self.diff_index
+                self.sel_index = self.show_from
+                self.re_render = True
             elif keypress == Keyboard.VK_ENTER:  # Enter
                 self.done = True
 
