@@ -20,7 +20,7 @@ from PyQt5.QtCore import QAbstractTableModel, QModelIndex, Qt, QVariant
 from PyQt5.QtGui import QPalette
 from PyQt5.QtWidgets import QTableView
 
-from hspylib.core.tools.collection_filter import CollectionFilter, FilterConditions
+from hspylib.core.tools.collection_filter import CollectionFilter, FilterCondition
 from hspylib.core.tools.commons import class_attribute_names, class_attribute_values
 
 T = TypeVar('T')
@@ -112,7 +112,7 @@ class HTableModel(QAbstractTableModel):
         self,
         name: str,
         el_name: str,
-        condition: FilterConditions,
+        condition: FilterCondition,
         el_value: Union[int, str, bool, float]) -> None:
         """TODO"""
         self._filters.apply_filter(name, el_name, condition, el_value)
